@@ -4,7 +4,7 @@ from platonic.queue.errors import (
     MessageTooLarge,
     QueueDoesNotExist,
 )
-from platonic.queue.input import InputQueue
 from platonic.queue.message import Message
-from platonic.queue.output import OutputQueue
+from platonic.queue.receiver import Receiver
+from platonic.queue.sender import Sender
 from platonic.queue.types import InternalType, ValueType
