@@ -1,12 +1,14 @@
 from abc import ABC
 from functools import cached_property
-from typing import Generic, Type
+from typing import Generic, Type, TypeVar
 
 from typecasts import Typecasts
 
-from platonic.queue.types import InternalType, ValueType
+from platonic.queue.types import InternalType
 from platonic.type_args import generic_type_args
 
+ValueType = TypeVar('ValueType')
+
 
 class BaseQueue(ABC, Generic[ValueType]):
     """Base class for queues."""
